@@ -1,17 +1,22 @@
-# Copyrights 2007-2016 by [Mark Overmeer].
+# Copyrights 2007-2018 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use warnings;
-use strict;
+# This code is part of distribution XML-Compile-SOAP.  Meta-POD processed
+# with OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package XML::Compile::SOAP11;
 use vars '$VERSION';
-$VERSION = '3.20';
+$VERSION = '3.23';
 
 use base 'XML::Compile::SOAP';
 
-use Log::Report 'xml-compile-soap', syntax => 'SHORT';
+use warnings;
+use strict;
+
+use Log::Report              'xml-compile-soap';
+
 use XML::Compile::SOAP::Util qw/:soap11/;
 use XML::Compile::Util       qw/pack_type unpack_type type_of_node/;
 
